/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.apio.architect.test.util.internal.form;

import java.util.function.Function;

import org.hamcrest.Description;
import org.hamcrest.Matcher;
import org.hamcrest.TypeSafeDiagnosingMatcher;

/**
 * Provides a {@code Matcher} that checks if the element returned by a function
 * matches another specific {@code Matcher}.
 *
 * @author Alejandro Hernández
 */
public class IsReturnedIn<T> extends TypeSafeDiagnosingMatcher<T> {

	public IsReturnedIn(Function<T, ?> function, Matcher<?> matcher) {
		_function = function;
		_matcher = matcher;
	}

	@Override
	public void describeTo(Description description) {
		description.appendText(
			"should return something that "
		).appendDescriptionOf(
			_matcher
		);
	}

	@Override
	protected boolean matchesSafely(T t, Description description) {
		Object result = _function.apply(t);

		if (!_matcher.matches(result)) {
			description.appendText(
				"should have returned something that "
			).appendDescriptionOf(
				_matcher
			).appendText(
				" instead of "
			).appendText(
				String.valueOf(result)
			);

			return false;
		}

		return true;
	}

	private final Function<T, ?> _function;
	private final Matcher<?> _matcher;

}