/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.apio.architect.test.util.internal.writer;

import static com.liferay.apio.architect.test.util.writer.MockWriterUtil.getRequestInfo;

import com.liferay.apio.architect.impl.message.json.EntryPointMessageMapper;
import com.liferay.apio.architect.impl.writer.EntryPointWriter;
import com.liferay.apio.architect.impl.writer.EntryPointWriter.Builder;

import java.util.Arrays;

/**
 * Provides methods that test {@code EntryPointMessageMapper} objects.
 *
 * <p>
 * This class shouldn't be instantiated.
 * </p>
 *
 * @author Alejandro Hernández
 */
public class MockEntryPointWriter {

	/**
	 * Writes an {@link EntryPoint}.
	 *
	 * @param  entryPointMessageMapper the {@link EntryPointMessageMapper} to
	 *         use for writing the JSON object
	 * @return the {@code String} containing the JSON Object.
	 * @review
	 */
	public static String write(
		EntryPointMessageMapper entryPointMessageMapper) {

		EntryPointWriter entryPointWriter = Builder.entryPoint(
			() -> Arrays.asList("type1", "type2", "type3")
		).entryPointMessageMapper(
			entryPointMessageMapper
		).requestInfo(
			getRequestInfo()
		).build();

		return entryPointWriter.write();
	}

	private MockEntryPointWriter() {
		throw new UnsupportedOperationException();
	}

}